summaryrefslogtreecommitdiff
path: root/src/core/misc.h
diff options
context:
space:
mode:
authorTimo Sirainen <cras@irssi.org>2001-03-03 17:34:35 +0000
committercras <cras@dbcabf3a-b0e7-0310-adc4-f8d773084564>2001-03-03 17:34:35 +0000
commita47ce2c449575f0c3212779bdfc1e69cab41aab1 (patch)
treebb8a77633aeeb47fd9abc94b806aeb53e889ab0a /src/core/misc.h
parent2f4969aefc2cb4d3928807c4f4f797bea33c853f (diff)
downloadirssi-a47ce2c449575f0c3212779bdfc1e69cab41aab1.zip
Added strstr_full() and strstr_full_case()
git-svn-id: http://svn.irssi.org/repos/irssi/trunk@1309 dbcabf3a-b0e7-0310-adc4-f8d773084564
Diffstat (limited to 'src/core/misc.h')
-rw-r--r--src/core/misc.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/core/misc.h b/src/core/misc.h
index b56e8f97..80cf87be 100644
--- a/src/core/misc.h
+++ b/src/core/misc.h
@@ -38,8 +38,13 @@ GSList *hashtable_get_keys(GHashTable *hash);
/* strstr() with case-ignoring */
char *stristr(const char *data, const char *key);
-/* stristr(), but matches only for full words */
+
+/* like strstr(), but matches only for full words.
+ `icase' specifies if match is case sensitive */
+char *strstr_full_case(const char *data, const char *key, int icase);
+char *strstr_full(const char *data, const char *key);
char *stristr_full(const char *data, const char *key);
+
/* easy way to check if regexp matches */
int regexp_match(const char *str, const char *regexp);